@@ -1,23 +1,33 @@
 #' @title Get model parameters
 #' @name get_parameters
 #'
-#' @description Returns the point estimates (or posterior samples for Bayesian
+#' @description Returns the coefficients (or posterior samples for Bayesian
 #'    models) from a model.
 #'
 #' @param iterations Number of posterior draws.
 #' @param progress Display progress.
 #' @param ... Currently not used.
-#' @inheritParams find_predictors
+#'
 #' @inheritParams find_parameters
+#' @inheritParams find_predictors
 #'
 #' @return \itemize{
 #'   \item for non-Bayesian models and if \code{effects = "fixed"}, a data frame with two columns: the parameter names and the related point estimates
-#'   \item if \code{effects = "random"}, a list of data frames with the random effects (as returned by \code{ranef()}
-#'   \item for Bayesian models, the posterior samples from the requested parameters as data frame.
-#'   \item for Anova (\code{aov()}) with error term, a list of parameters for the conditional, the within-subject and the between-subjects parameters
+#'   \item if \code{effects = "random"}, a list of data frames with the random effects (as returned by \code{ranef()}), unless the random effects have the same simplified structure as fixed effects (e.g. for models from \pkg{MCMCglmm})
+#'   \item for Bayesian models, the posterior samples from the requested parameters as data frame
+#'   \item for Anova (\code{aov()}) with error term, a list of parameters for the conditional and the random effects parameters
 #'   \item for models with smooth terms or zero-inflation component, a data frame with three columns: the parameter names, the related point estimates and the component
 #' }
 #'
+#' @details In most cases when models either return different "effects" (fixed,
+#' random) or "components" (conditional, zero-inflated, ...), the arguments
+#' \code{effects} and \code{component} can be used.
+#' \cr \cr
+#' \code{get_parameters()} is comparable to \code{coef()}, however, the coefficients
+#' are returned as data frame (with columns for names and point estimates of
+#' coefficients). For Bayesian models, the posterior samples of parameters are
+#' returned.
+#'
 #' @examples
 #' data(mtcars)
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
@@ -29,9 +39,10 @@ get_parameters <- function(x, ...) {
 }
 
 
+
 #' @export
 get_parameters.default <- function(x, ...) {
-  if (inherits(x, "list") && obj_has_name(x, "gam")) {
+  if (inherits(x, "list") && .obj_has_name(x, "gam")) {
     x <- x$gam
     class(x) <- c(class(x), c("glm", "lm"))
     return(get_parameters.gam(x, ...))
@@ -61,12 +72,27 @@ get_parameters.default <- function(x, ...) {
     )
   },
   error = function(x) {
+    print_color(sprintf("Parameters can't be retrieved for objects of class '%s'.\n", class(x)[1]), "red")
     NULL
   }
   )
 }
 
 
+
+#' @export
+get_parameters.polr <- function(x, ...) {
+  pars <- c(sprintf("Intercept: %s", names(x$zeta)), names(x$coefficients))
+  data.frame(
+    parameter = pars,
+    estimate = c(unname(x$zeta), unname(x$coefficients)),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+}
+
+
+
 #' @export
 get_parameters.gbm <- function(x, ...) {
   s <- summary(x, plotit = FALSE)
@@ -79,6 +105,86 @@ get_parameters.gbm <- function(x, ...) {
 }
 
 
+
+#' @export
+get_parameters.BBreg <- function(x, ...) {
+  pars <- summary(x)$coefficients
+  data.frame(
+    parameter = rownames(pars),
+    estimate = pars[, "Estimate"],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+}
+
+
+
+#' @rdname get_parameters
+#' @export
+get_parameters.BBmm <- function(x, effects = c("fixed", "random"), ...) {
+  effects <- match.arg(effects)
+
+  l <- .compact_list(list(
+    conditional = x$fixed.coef,
+    random = x$random.coef
+  ))
+
+  fixed <- data.frame(
+    parameter = rownames(l$conditional),
+    estimate = l$conditional,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  if (effects == "fixed") {
+    fixed
+  } else {
+    l$random
+  }
+}
+
+
+
+#' @rdname get_parameters
+#' @export
+get_parameters.glimML <- function(x, effects = c("fixed", "random", "all"), ...) {
+  effects <- match.arg(effects)
+
+  l <- .compact_list(list(
+    conditional = x@fixed.param,
+    random = x@random.param
+  ))
+
+  fixed <- data.frame(
+    parameter = names(l$conditional),
+    estimate = l$conditional,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  random <- data.frame(
+    parameter = names(l$random),
+    estimate = l$random,
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  all <- rbind(
+    cbind(fixed, data.frame(effects = "fixed", stringsAsFactors = FALSE)),
+    cbind(random, data.frame(effects = "random", stringsAsFactors = FALSE))
+  )
+
+  if (effects == "fixed") {
+    fixed
+  } else if (effects == "random") {
+    random
+  } else {
+    all
+  }
+}
+
+
+
 #' @export
 get_parameters.gamlss <- function(x, ...) {
   pars <- list(
@@ -103,6 +209,7 @@ get_parameters.gamlss <- function(x, ...) {
 }
 
 
+
 #' @export
 get_parameters.lrm <- function(x, ...) {
   tryCatch({
@@ -121,6 +228,7 @@ get_parameters.lrm <- function(x, ...) {
 }
 
 
+
 #' @export
 get_parameters.aov <- function(x, ...) {
   cf <- stats::coef(x)
@@ -133,12 +241,14 @@ get_parameters.aov <- function(x, ...) {
 }
 
 
+
 #' @export
 get_parameters.data.frame <- function(x, ...) {
   stop("A data frame is no valid object for this function")
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.gam <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
@@ -149,7 +259,7 @@ get_parameters.gam <- function(x, component = c("all", "conditional", "smooth_te
   smooth_terms <- st[, 1]
   names(smooth_terms) <- row.names(st)
 
-  return_smooth_parms(
+  .return_smooth_parms(
     conditional = pars[.grep_non_smoothers(names(pars))],
     smooth_terms = smooth_terms,
     component = component
@@ -157,13 +267,14 @@ get_parameters.gam <- function(x, component = c("all", "conditional", "smooth_te
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.vgam <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
   component <- match.arg(component)
   pars <- stats::coef(x)
 
-  return_smooth_parms(
+  .return_smooth_parms(
     conditional = pars[.grep_non_smoothers(names(pars))],
     smooth_terms = pars[.grep_smoothers(names(pars))],
     component = component
@@ -171,6 +282,7 @@ get_parameters.vgam <- function(x, component = c("all", "conditional", "smooth_t
 }
 
 
+
 #' @export
 get_parameters.crq <- function(x, ...) {
   sc <- summary(x)
@@ -181,6 +293,8 @@ get_parameters.crq <- function(x, ...) {
 }
 
 
+
+#' @rdname get_parameters
 #' @export
 get_parameters.rqss <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
   component <- match.arg(component)
@@ -189,7 +303,7 @@ get_parameters.rqss <- function(x, component = c("all", "conditional", "smooth_t
   smooth_terms <- sc$qsstab[, 3]
   names(smooth_terms) <- rownames(sc$qsstab)
 
-  return_smooth_parms(
+  .return_smooth_parms(
     conditional = sc$coef[ ,1],
     smooth_terms = smooth_terms,
     component = component
@@ -197,13 +311,14 @@ get_parameters.rqss <- function(x, component = c("all", "conditional", "smooth_t
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.Gam <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
   component <- match.arg(component)
   pars <- stats::coef(x)
 
-  return_smooth_parms(
+  .return_smooth_parms(
     conditional = pars[.grep_non_smoothers(names(pars))],
     smooth_terms = pars[.grep_smoothers(names(pars))],
     component = component
@@ -211,21 +326,24 @@ get_parameters.Gam <- function(x, component = c("all", "conditional", "smooth_te
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.zeroinfl <- function(x, component = c("all", "conditional", "zi", "zero_inflated"), ...) {
   component <- match.arg(component)
-  return_zeroinf_parms(x, component)
+  .return_zeroinf_parms(x, component)
 }
 
 
+
 #' @export
 get_parameters.zerotrunc <- function(x, component = c("all", "conditional", "zi", "zero_inflated"), ...) {
   component <- match.arg(component)
-  return_zeroinf_parms(x, component)
+  .return_zeroinf_parms(x, component)
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.gamm <- function(x, component = c("all", "conditional", "smooth_terms"), ...) {
@@ -235,8 +353,12 @@ get_parameters.gamm <- function(x, component = c("all", "conditional", "smooth_t
 }
 
 
+
+#' @rdname get_parameters
 #' @export
-get_parameters.aovlist <- function(x, ...) {
+get_parameters.aovlist <- function(x, effects = c("fixed", "random", "all"), ...) {
+  effects <- match.arg(effects)
+
   l <- lapply(stats::coef(x), function(i) {
     data.frame(
       parameter = names(i),
@@ -244,25 +366,42 @@ get_parameters.aovlist <- function(x, ...) {
       stringsAsFactors = FALSE
     )
   })
-  names(l) <- c("conditional", "between", "within")
-  l
+
+  l <- list(rbind(l[[1]], l[[2]]), l[[3]])
+  names(l) <- c("conditional", "random")
+
+  all <- rbind(
+    cbind(l$conditional, data.frame(effects = "fixed", stringsAsFactors = FALSE)),
+    cbind(l$random, data.frame(effects = "random", stringsAsFactors = FALSE))
+  )
+
+  if (effects == "fixed") {
+    l$conditional
+  } else if (effects == "random") {
+    l$random
+  } else {
+    all
+  }
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.hurdle <- function(x, component = c("all", "conditional", "zi", "zero_inflated"), ...) {
   component <- match.arg(component)
-  return_zeroinf_parms(x, component)
+  .return_zeroinf_parms(x, component)
 }
 
 
+
+#' @rdname get_parameters
 #' @export
-get_parameters.MCMCglmm <- function(x, effects = c("fixed", "random"), ...) {
+get_parameters.MCMCglmm <- function(x, effects = c("fixed", "random", "all"), ...) {
   effects <- match.arg(effects)
   sc <- summary(x)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = sc$solutions[, 1],
     random = sc$Gcovariances[, 1]
   ))
@@ -282,14 +421,22 @@ get_parameters.MCMCglmm <- function(x, effects = c("fixed", "random"), ...) {
     stringsAsFactors = FALSE
   )
 
+  all <- rbind(
+    cbind(fixed, data.frame(effects = "fixed", stringsAsFactors = FALSE)),
+    cbind(random, data.frame(effects = "random", stringsAsFactors = FALSE))
+  )
+
   if (effects == "fixed") {
     fixed
-  } else {
+  } else if (effects == "random") {
     random
+  } else {
+    all
   }
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.coxme <- function(x, effects = c("fixed", "random"), ...) {
@@ -299,7 +446,7 @@ get_parameters.coxme <- function(x, effects = c("fixed", "random"), ...) {
 
   effects <- match.arg(effects)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x),
     random = lme4::ranef(x)
   ))
@@ -318,6 +465,7 @@ get_parameters.coxme <- function(x, effects = c("fixed", "random"), ...) {
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.merMod <- function(x, effects = c("fixed", "random"), ...) {
@@ -327,7 +475,7 @@ get_parameters.merMod <- function(x, effects = c("fixed", "random"), ...) {
 
   effects <- match.arg(effects)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x),
     random = lme4::ranef(x)
   ))
@@ -346,6 +494,7 @@ get_parameters.merMod <- function(x, effects = c("fixed", "random"), ...) {
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.rlmerMod <- function(x, effects = c("fixed", "random"), ...) {
@@ -355,7 +504,7 @@ get_parameters.rlmerMod <- function(x, effects = c("fixed", "random"), ...) {
 
   effects <- match.arg(effects)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x),
     random = lme4::ranef(x)
   ))
@@ -374,6 +523,7 @@ get_parameters.rlmerMod <- function(x, effects = c("fixed", "random"), ...) {
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.mixed <- function(x, effects = c("fixed", "random"), ...) {
@@ -383,7 +533,7 @@ get_parameters.mixed <- function(x, effects = c("fixed", "random"), ...) {
 
   effects <- match.arg(effects)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x$full_model),
     random = lme4::ranef(x$full_model)
   ))
@@ -402,6 +552,7 @@ get_parameters.mixed <- function(x, effects = c("fixed", "random"), ...) {
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.lme <- function(x, effects = c("fixed", "random"), ...) {
@@ -411,7 +562,7 @@ get_parameters.lme <- function(x, effects = c("fixed", "random"), ...) {
 
   effects <- match.arg(effects)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x),
     random = lme4::ranef(x)
   ))
@@ -430,6 +581,7 @@ get_parameters.lme <- function(x, effects = c("fixed", "random"), ...) {
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.MixMod <- function(x, effects = c("fixed", "random"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion"), ...) {
@@ -461,7 +613,7 @@ get_parameters.MixMod <- function(x, effects = c("fixed", "random"), component =
   }
 
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x, sub_model = "main"),
     random = re[grepl("^(?!zi_)", re.names, perl = TRUE)],
     zero_inflated = z_inflated,
@@ -497,7 +649,7 @@ get_parameters.MixMod <- function(x, effects = c("fixed", "random"), component =
   } else if (effects == "random") {
     switch(
       component,
-      all = compact_list(list(random = l$random, zero_inflated_random = l$zero_inflated_random)),
+      all = .compact_list(list(random = l$random, zero_inflated_random = l$zero_inflated_random)),
       conditional = list(random = l$random),
       zi = ,
       zero_inflated = list(zero_inflated_random = l$zero_inflated_random)
@@ -506,6 +658,7 @@ get_parameters.MixMod <- function(x, effects = c("fixed", "random"), component =
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.glmmTMB <- function(x, effects = c("fixed", "random"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion"), ...) {
@@ -516,7 +669,7 @@ get_parameters.glmmTMB <- function(x, effects = c("fixed", "random"), component
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  l <- compact_list(list(
+  l <- .compact_list(list(
     conditional = lme4::fixef(x)$cond,
     random = lme4::ranef(x)$cond,
     zero_inflated = lme4::fixef(x)$zi,
@@ -549,7 +702,7 @@ get_parameters.glmmTMB <- function(x, effects = c("fixed", "random"), component
   } else if (effects == "random") {
     switch(
       component,
-      all = compact_list(list(random = l$random, zero_inflated_random = l$zero_inflated_random)),
+      all = .compact_list(list(random = l$random, zero_inflated_random = l$zero_inflated_random)),
       conditional = l$random,
       zi = ,
       zero_inflated = l$zero_inflated_random
@@ -558,9 +711,10 @@ get_parameters.glmmTMB <- function(x, effects = c("fixed", "random"), component
 }
 
 
+
 #' @rdname get_parameters
 #' @export
-get_parameters.brmsfit <- function(x, effects = c("fixed", "random", "all"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "simplex", "smooth_terms"), parameters = NULL, ...) {
+get_parameters.brmsfit <- function(x, effects = c("fixed", "random", "all"), component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "simplex", "sigma", "smooth_terms"), parameters = NULL, ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
@@ -569,24 +723,26 @@ get_parameters.brmsfit <- function(x, effects = c("fixed", "random", "all"), com
     elements <- .get_elements(effects, component)
     as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]))]
   } else {
-    as.data.frame(x)[get_parms_data(x, effects, component, parameters)]
+    as.data.frame(x)[.get_parms_data(x, effects, component, parameters)]
   }
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.stanreg <- function(x, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
   effects <- match.arg(effects)
-  as.data.frame(x)[get_parms_data(x, effects, "all", parameters)]
+  as.data.frame(x)[.get_parms_data(x, effects, "all", parameters)]
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.BFBayesFactor <- function(x, iterations = 4000, progress = FALSE, ...) {
   if (!requireNamespace("BayesFactor", quietly = TRUE)) {
-    stop("This function needs `BayesFactor` to be installed.")
+    stop("This function requires package `BayesFactor` to work. Please install it.")
   }
 
   if (.classify_BFBayesFactor(x) == "correlation") {
@@ -613,6 +769,7 @@ get_parameters.BFBayesFactor <- function(x, iterations = 4000, progress = FALSE,
 }
 
 
+
 #' @rdname get_parameters
 #' @export
 get_parameters.stanmvreg <- function(x, effects = c("fixed", "random", "all"), parameters = NULL, ...) {
@@ -628,19 +785,24 @@ get_parameters.stanmvreg <- function(x, effects = c("fixed", "random", "all"), p
       i, "|",
       substr(parms[[i]]$random, start = find_bracket + 1, stop = 1000000L)
     )
+    parms[[i]]$sigma <- NULL
   }
 
-  as.data.frame(x)[unlist(lapply(parms, function(i) i[elements]))]
+  as.data.frame(x)[unlist(lapply(.compact_list(parms), function(i) i[elements]))]
 }
 
 
-get_parms_data <- function(x, effects, component, parameters = NULL) {
+
+
+
+.get_parms_data <- function(x, effects, component, parameters = NULL) {
   elements <- .get_elements(effects, component)
   unlist(find_parameters(x, flatten = FALSE, parameters = parameters)[elements])
 }
 
 
-return_zeroinf_parms <- function(x, component) {
+
+.return_zeroinf_parms <- function(x, component) {
   cf <- stats::coef(x)
 
   conditional <- grepl("^count_", names(cf), perl = TRUE)
@@ -678,7 +840,8 @@ return_zeroinf_parms <- function(x, component) {
 }
 
 
-return_smooth_parms <- function(conditional, smooth_terms, component) {
+
+.return_smooth_parms <- function(conditional, smooth_terms, component) {
   cond <- data.frame(
     parameter = names(conditional),
     estimate = conditional,
