@@ -29,7 +29,7 @@ link_function <- function(x, ...) {
 
 #' @export
 link_function.default <- function(x, ...) {
-  if (inherits(x, "list") && obj_has_name(x, "gam")) {
+  if (inherits(x, "list") && .obj_has_name(x, "gam")) {
     x <- x$gam
     class(x) <- c(class(x), c("glm", "lm"))
   }
@@ -71,6 +71,24 @@ link_function.multinom <- function(x, ...) {
 }
 
 
+#' @export
+link_function.BBreg <- function(x, ...) {
+  stats::make.link(link = "logit")$linkfun
+}
+
+
+#' @export
+link_function.BBmm <- function(x, ...) {
+  stats::make.link(link = "logit")$linkfun
+}
+
+
+#' @export
+link_function.glimML <- function(x, ...) {
+  stats::make.link(link = x@link)$linkfun
+}
+
+
 #' @export
 link_function.gamlss <- function(x, ...) {
   faminfo <- get(x$family[1], asNamespace("gamlss"))()
@@ -346,6 +364,12 @@ link_function.coxph <- function(x, ...) {
 }
 
 
+#' @export
+link_function.survfit <- function(x, ...) {
+  stats::make.link("logit")$linkfun
+}
+
+
 #' @export
 link_function.coxme <- function(x, ...) {
   stats::make.link("logit")$linkfun
