@@ -67,8 +67,8 @@ if (require("testthat") && require("insight") && require("stats")) {
   })
 
   test_that("find_terms", {
-    expect_equal(find_terms(m1), list(response = "yield", conditional = c("N", "P", "K", "block")))
-    expect_equal(find_terms(m1, flatten = TRUE), c("yield", "N", "P", "K", "block"))
+    expect_equal(find_terms(m1), list(response = "yield", conditional = c("N", "P", "K", "Error(block)")))
+    expect_equal(find_terms(m1, flatten = TRUE), c("yield", "N", "P", "K", "Error(block)"))
     expect_equal(find_terms(m2), list(response = "yield", conditional = c("N", "P", "K")))
     expect_equal(find_terms(m2, flatten = TRUE), c("yield", "N", "P", "K"))
   })
@@ -87,12 +87,19 @@ if (require("testthat") && require("insight") && require("stats")) {
     expect_equal(
       find_parameters(m1),
       list(
-        conditional = "(Intercept)",
-        between = "N1:P1:K1",
-        within = c("N1", "P1", "K1", "N1:P1", "N1:K1", "P1:K1")
+        conditional = c("(Intercept)", "N1:P1:K1"),
+        random = c("N1", "P1", "K1", "N1:P1", "N1:K1", "P1:K1")
       )
     )
-    expect_equal(length(get_parameters(m1)), 3)
+
+    expect_equal(length(get_parameters(m1)), 2)
+    expect_equal(nrow(get_parameters(m1, effects = "all")), 8)
+
+    expect_equal(
+      get_parameters(m1, effects = "all")$effects,
+      c("fixed", "fixed", "random", "random", "random", "random", "random", "random")
+    )
+
     expect_equal(
       find_parameters(m2),
       list(
