@@ -44,9 +44,9 @@ if (require("testthat") && require("insight") && require("pscl")) {
     )
   })
 
-  test_that("find_terms", {
-    expect_equal(find_terms(m1), list(response = "art", conditional = c("fem", "mar", "kid5", "ment"), zero_inflated = c("kid5", "phd")))
-    expect_equal(find_terms(m1, flatten = TRUE), c("art", "fem", "mar", "kid5", "ment", "phd"))
+  test_that("find_variables", {
+    expect_equal(find_variables(m1), list(response = "art", conditional = c("fem", "mar", "kid5", "ment"), zero_inflated = c("kid5", "phd")))
+    expect_equal(find_variables(m1, flatten = TRUE), c("art", "fem", "mar", "kid5", "ment", "phd"))
   })
 
   test_that("n_obs", {
@@ -74,9 +74,9 @@ if (require("testthat") && require("insight") && require("pscl")) {
     expect_false(is_multivariate(m1))
   })
 
-  test_that("find_variables", {
+  test_that("find_terms", {
     expect_equal(
-      find_variables(m1),
+      find_terms(m1),
       list(
         response = "art",
         conditional = c("fem", "mar", "kid5", "ment"),
