@@ -110,7 +110,7 @@ if (.runThisTest) {
       expect_identical(find_terms(m1), list(
         response = "Reaction",
         conditional = "Days",
-        random = "Subject"
+        random = c("Days", "Subject")
       ))
       expect_identical(find_terms(m1, flatten = TRUE), c("Reaction", "Days", "Subject"))
       expect_identical(find_terms(m2), list(
@@ -121,6 +121,14 @@ if (.runThisTest) {
       expect_identical(find_terms(m2, flatten = TRUE), c("Reaction", "Days", "mysubgrp", "mygrp", "Subject"))
     })
 
+    test_that("find_variables", {
+      expect_identical(find_variables(m1), list(
+        response = "Reaction",
+        conditional = "Days",
+        random = "Subject"
+      ))
+    })
+
     test_that("get_response", {
       expect_identical(get_response(m1), sleepstudy$Reaction)
     })
