@@ -1,5 +1,5 @@
 if (require("testthat") && require("insight") && require("truncreg") && require("survival")) {
-  context("insight, model_info")
+  context("insight, truncreg")
 
   data("tobin", package = "survival")
   m1 <- truncreg(durable ~ age + quant, data = tobin, subset = durable > 0)
